import 'package:equatable/equatable.dart';

abstract class RegisterUserState extends Equatable {
  const RegisterUserState();

  @override
  List<Object> get props => [];
}

class RegisterUserInitial extends RegisterUserState {}

class RegisterUserLoading extends RegisterUserState {}

class RegisterUserSuccess extends RegisterUserState {}

class RegisterUserFailure extends RegisterUserState {
  final String error;

  const RegisterUserFailure(this.error);

  @override
  List<Object> get props => [error];
}

class RegisterUserFieldsState extends RegisterUserState {
  final bool areFieldsFilled;

  const RegisterUserFieldsState(this.areFieldsFilled);

  @override
  List<Object> get props => [areFieldsFilled];
}
